@@ -1,9 +1,13 @@
 #'@title Get optimality values
 #'
-#'@description Returns a list of optimality values (or one value in particular)
+#'@description Returns a list of optimality values (or one value in particular).
 #'
-#'@param output The output of either gen_design or eval_design/eval_design_mc
+#'Note: The choice of contrast will effect the `G` efficiency value, and `gen_design()`
+#'and `eval_design()` by default set different contrasts (`contr.simplex` vs `contr.sum`).
+#'
+#'@param output The output of either gen_design or eval_design/eval_design_mc.
 #'@param optimality Default `NULL`. Return just the specific optimality requested.
+#'@param calc_g Default `FALSE`. Whether to calculate the g-efficiency.
 #'@return A dataframe of optimality conditions. `D`, `A`, and `G` are efficiencies (value is out of 100).
 #'`T` is the trace of the information matrix, `E` is the minimum eigenvalue of the information matrix,
 #'`I` is the average prediction variance, and `Alias` is the trace of the alias matrix.
@@ -30,10 +34,25 @@
 #'                           alpha = 0.05, detailedoutput = TRUE)
 #'
 #'get_optimality(power_output)
-get_optimality = function(output, optimality = NULL) {
+get_optimality = function(output, optimality = NULL, calc_g = FALSE) {
   if(is.null(attr(output, "D"))) attr(output, "D") = NA
   if(is.null(attr(output, "A"))) attr(output, "A") = NA
-  if(is.null(attr(output, "G"))) attr(output, "G") = NA
+  if(!is.null(attr(output, "augmented"))) {
+    if(!attr(output, "augmented") && !attr(output, "splitplot") && calc_g) {
+      attr(output, "G") = calculate_gefficiency(output, calculation_type = "random",
+                                                randsearches = 1000)
+    } else {
+      attr(output, "G") = "Not Computed"
+    }
+  } else {
+    if(!attr(output, "blocking")) {
+      attr(output, "G") = calculate_gefficiency(output, calculation_type = "random",
+                                                randsearches = 1000)
+    } else {
+      attr(output, "G") = "Not Computed"
+    }
+  }
+  if(is.null(attr(output, "G"))) attr(output, "G") = "Not Computed"
   if(is.null(attr(output, "T"))) attr(output, "T") = NA
   if(is.null(attr(output, "E"))) attr(output, "E") = NA
   if(is.null(attr(output, "variance.matrix"))) attr(output, "variance.matrix") = NA
@@ -57,7 +76,7 @@ get_optimality = function(output, optimality = NULL) {
       optimality = "A"
     }
     if(!optimality %in% c("D","A","I","G","E","T","Alias")) {
-      stop("Optimality `",optimality,"` not in ", paste0(c("D","A","I","G","E","T","Alias"),collapse=", "))
+      stop("skpr: Optimality `",optimality,"` not in ", paste0(c("D","A","I","G","E","T","Alias"),collapse=", "))
     }
     return(optimality_df[optimality])
   }
